summaryrefslogtreecommitdiffstats
path: root/src/inactivity.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/inactivity.cpp')
-rw-r--r--src/inactivity.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/inactivity.cpp b/src/inactivity.cpp
index 5c808b7..d1d9204 100644
--- a/src/inactivity.cpp
+++ b/src/inactivity.cpp
@@ -53,8 +53,8 @@ inactivity::inactivity() {
int dummy = 0;
has_XSC_Extension = XScreenSaverQueryExtension( qt_xdisplay(), &dummy, &dummy );
- checkInactivity = new QTimer( this );
- connect( checkInactivity, SIGNAL(timeout()), this, SLOT(check()));
+ checkInactivity = new TQTimer( this );
+ connect( checkInactivity, TQT_SIGNAL(timeout()), this, TQT_SLOT(check()));
kdDebugFuncOut(trace);
}
@@ -72,13 +72,13 @@ inactivity::~inactivity() {
/*!
* This function start the monitoring of inactivity of user on the X-Server.
* Here wee set the time for the signal \ref inactivityTimeExpired() and start
* the needed QTimer.
* \param timeToExpire Integer value representing the time of inactivity which need
* to elapse befor send signal. The time is in seconds.
* \param blacked QStringList with blacklisted programs which if detected with
* pidof() as running prevent the autosuspend.
*/
-void inactivity::start( int timeToExpire, QStringList blacked ) {
+void inactivity::start( int timeToExpire, TQStringList blacked ) {
kdDebugFuncIn(trace);
blacklist = blacked;
@@ -93,7 +93,7 @@ void inactivity::start( int timeToExpire, QStringList blacked ) {
}
/*!
* \b SLOT to call check as recheck inactivity if befor a running PID
* request was detected.
*/
void inactivity::recheck() {
@@ -105,14 +105,14 @@ void inactivity::recheck() {
}
/*!
* \b SLOT to call check without a recheck.
*/
void inactivity::check() {
check(false);
}
/*!
* \b SLOT to check the current idle-time of the X-Server and if there
* are blacklisted programs are running. If the through \ref timeToInactivity
* defined time is expired, this function emit signal \ref inactivityTimeExpired() .
* \param recheck boolean which define if this is a recheck or not.
@@ -143,7 +143,7 @@ void inactivity::check( bool recheck ) {
}
else {
//called if there is a getPIDs() is running
- QTimer::singleShot(500, this, SLOT(recheck()));
+ TQTimer::singleShot(500, this, TQT_SLOT(recheck()));
}
}
else checkInactivity->start(CHECK_for_INACTIVITY, true);
@@ -288,10 +288,10 @@ void inactivity::checkBlacklisted(){
proc = new KProcess;
*proc << "pidof" << blacklist;
- connect( proc, SIGNAL(receivedStdout(KProcess *, char *, int)),this,
- SLOT(getPIDs(KProcess *, char *, int)));
- connect( proc, SIGNAL(processExited(KProcess *)),
- SLOT(getPIDsExited(KProcess *)));
+ connect( proc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)),this,
+ TQT_SLOT(getPIDs(KProcess *, char *, int)));
+ connect( proc, TQT_SIGNAL(processExited(KProcess *)),
+ TQT_SLOT(getPIDsExited(KProcess *)));
if (!proc->start(KProcess::NotifyOnExit, KProcess::AllOutput))
{
@@ -309,7 +309,7 @@ void inactivity::checkBlacklisted(){
/*!
* \b SLOT to get the return of the command pidof and parse this to set
* \ref blacklisted_running .
* \param *proc pointer to the sending KProcess
* \param *buffer the char pointer to the output of the process to stdout
@@ -318,14 +318,14 @@ void inactivity::checkBlacklisted(){
void inactivity::getPIDs(KProcess */*proc*/, char *buffer, int /*lenght*/) {
kdDebugFuncIn(trace);
- QString pids(buffer);
+ TQString pids(buffer);
pids.remove(" ");
if(pids.isEmpty() || pids == "\n" ) {
kdDebug() << "NO! BLACKLISTED IS RUNNING" << endl;
blacklisted_running = false;
}
else {
- if (pids.contains(QRegExp("[0-9]"))) {
+ if (pids.tqcontains(TQRegExp("[0-9]"))) {
kdDebug() << "BLACKLISTED IS RUNNING" << endl;
blacklisted_running = true;
blacklisted_running_last = idleTime;
@@ -342,7 +342,7 @@ void inactivity::getPIDs(KProcess */*proc*/, char *buffer, int /*lenght*/) {
/*!
* \b SLOT which called if the call of pidof is exited
* \param proc the KPocess which called this SLOT
*/
void inactivity::getPIDsExited(KProcess *proc){
@@ -72,13 +72,13 @@ inactivity::~inactivity() {
* This function start the monitoring of inactivity of user on the X-Server.
* Here wee set the time for the signal \ref inactivityTimeExpired() and start
- * the needed QTimer.
+ * the needed TQTimer.
* \param timeToExpire Integer value representing the time of inactivity which need
* to elapse befor send signal. The time is in seconds.
@@ -72,13 +72,13 @@ inactivity::~inactivity() {
* \param timeToExpire Integer value representing the time of inactivity which need
* to elapse befor send signal. The time is in seconds.
- * \param blacked QStringList with blacklisted programs which if detected with
+ * \param blacked TQStringList with blacklisted programs which if detected with
* pidof() as running prevent the autosuspend.
*/
@@ -93,7 +93,7 @@ void inactivity::start( int timeToExpire, QStringList blacked ) {
}
/*!
- * \b SLOT to call check as recheck inactivity if befor a running PID
+ * \b TQT_SLOT to call check as recheck inactivity if befor a running PID
* request was detected.
*/
@@ -105,14 +105,14 @@ void inactivity::recheck() {
}
/*!
- * \b SLOT to call check without a recheck.
+ * \b TQT_SLOT to call check without a recheck.
*/
void inactivity::check() {
@@ -105,14 +105,14 @@ void inactivity::recheck() {
}
/*!
- * \b SLOT to check the current idle-time of the X-Server and if there
+ * \b TQT_SLOT to check the current idle-time of the X-Server and if there
* are blacklisted programs are running. If the through \ref timeToInactivity
* defined time is expired, this function emit signal \ref inactivityTimeExpired() .
@@ -309,7 +309,7 @@ void inactivity::checkBlacklisted(){
/*!
- * \b SLOT to get the return of the command pidof and parse this to set
+ * \b TQT_SLOT to get the return of the command pidof and parse this to set
* \ref blacklisted_running .
* \param *proc pointer to the sending KProcess
@@ -342,7 +342,7 @@ void inactivity::getPIDs(KProcess */*proc*/, char *buffer, int /*lenght*/) {
/*!
- * \b SLOT which called if the call of pidof is exited
+ * \b TQT_SLOT which called if the call of pidof is exited
* \param proc the KPocess which called this SLOT
*/